package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"`!0````!$``8H````#0``-+````````T`"``
M"0`H`!X`'0````8````T$```-!```#0```$@```!(`````4````$`````P``
M`500``%4$``!5`````T````-````!`````$````!`````!`````0``````"_
M^```O_@````%``$```````$``,[H$`'.Z!`!SN@```)T```2J`````8``0``
M`````@``SP@0`<\($`'/"````.@```#H````!@````0````$```!9!```600
M``%D````1````$0````$````!&1TY5```+^X$`"_N!``O[@````4````%```
M``0````$9'3E40``````````````````````````````!@````1D=.52``#.
MZ!`!SN@0`<[H```!&````1@````$`````2]L:6(O;&0N<V\N,0`````````$
M````$`````%'3E4```````````(````&````#P````0````4`````T=.50"_
M-,?)9R%4#\6KFSC5BH`-CA[[JP```!$```!3````"`````@$$!``@`1`)0$`
M`*BH`8:B`B`$0`D$*`]%,J(X"`R$B@```%,```!5````6@```%\```!@````
M9P```&H```!K````;````&\`````````<0```'(```!S````=```````````
M:TKP>B`+(J'&!9A&']_%;@[OT^HM1][.?)I_:[:;Q2X.Y/\@Q8Y!?`[QC;A\
MU&35'%AQV0'&1^+`XTNL'=/;\GR2X[HL/^7"8&RA^F^+`;/60PEJJ6'*E(&<
M^8=FS*]G[-5%0Y[B%`Q[7^_F<;+5R9[CS=KMVV(S"Y<Z#9N<J7\*`J?A2?O@
MHP````````````````````````.4```````````2```````$,P``````````
M$@```````M$``````````!(```````1,```````````1```````$M0``````
M````$@```````$(``````````!(```````0D```````````2```````!I@``
M````````$@```````(\``````````!(```````.A```````````2````````
M_0``````````$@```````YL``````````!(```````'^```````````2````
M```!;@``````````$@```````,@``````````!(```````&A```````````2
M```````!@```````````$@```````TL``````````!(```````/A````````
M```2````````L0``````````$@```````UP``````````!(```````).````
M```````2```````#\0``````````$@```````>H``````````!(```````/H
M```````````2```````!R@``````````$@```````1T``````````!(`````
M``$+```````````2```````"F```````````$@```````2\``````````!(`
M``````(U```````````2```````#&@``````````$@```````LD`````````
M`!(```````-X```````````2```````"A0``````````$@```````VD`````
M`````!(```````*1```````````2```````"'```````````$@```````_@`
M`````````!(````````1```````````@```````#+```````````$@``````
M!`4``````````!(```````!4```````````2```````#A@``````````$@``
M````!#H``````````!(```````+"```````````2```````!4```````````
M$@``````!!8``````````!(```````#7```````````2```````"0P``````
M````$@```````XT``````````!(```````-C```````````2```````#.0``
M````````$@```````NH``````````!(```````-Q```````````2````````
M-```````````$@```````:L``````````!(```````.H```````````2````
M```">@``````````$@```````5T``````````!(```````0L```````````2
M```````#?P``````````$@``````!$T``````````"$```````)<````````
M```2````````(```````````(````````4$``````````!(```````(L````
M```````2```````$#```````````$@```````'@``````````!(```````!C
M```````````2```````!C0``````````$@```````S$``````````!(`````
M``1.```````````1```````#R0``````````$@```````M8``````````!(`
M``````.V```````````2```````"^P``````````$@```````T(`````````
M`!(```````/!```````````2```````#TP``````````$@```````=@`````
M`````!(```````#L```````````2```````":A``6A``````$@``````!8P0
M`=%4````!!$``!D```1^$`'16`````01```9```$OA``5L````#0$@``#```
M!'@0`&```````!(```T```3C$`!'C```"NP2```,```$1Q``%D````)@$@``
M#```!)(0`#Z\````#!(```P```5#$``^R````EP2```,```%<!``5Y````!4
M$@``#```!3T0`!7H`````!(```L```6@$`!2>```!$@2```,```$71`!T5P`
M````$`#_\0``!,H0`$$D````4!(```P```,+$`!@2`````01```.```"HQ`!
MT6`````3$0``&@``!&D0`>&0`````!``__$```4[$``]2````$@2```,```%
M4!``1AP```%P$@``#```!6(0`$5H````@!(```P```3P$`'11``````0```8
M```%(Q`"450`````$```&0```*`0`%UP`````!(```````37$`!!=````<02
M```,```$5A`!T5P`````$`#_\0``!&X0`%D`````!!(```P```2#$`!CQ```
M6^H1```.```!MQ``7,``````$@``````!1,0`%A`````P!(```P```3V$``8
MH````"02```,```$\A`!T40`````(```&```!*,0`$7H````-!(```P```3]
M$``]]````,@2```,```%+A``0S@```(P$@``#`!L:6)P97)L+G-O+C4N,3(`
M7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T
M97)M`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X
M:71?9FQA9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M
M<&-V7W!T<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P
M='(`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])
M<&%R<V5R7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E
M<FQ?271O<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T
M<'9N`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V
M86Q?<'1R`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?
M9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S
M971P=@!097)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E
M<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D`'!T:')E861?9V5T
M<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L:6)C+G-O+C8`7TE/
M7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?
M<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER
M`')E86QL;V,`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S
M=')S='(`<FUD:7(`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O
M<&5N9&ER`%]?>'-T870V-`!?7V-T>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN
M:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I
M;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA
M:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C
M<W5?9FEN:0!N86UE7VQO861?;7E?<&%R7W!L`'!A<E]C=7)R96YT7V5X96,`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A
M<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!?4T1!7T)!
M4T5?`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T
M=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%
M05)35$%#2P!S:7IE7VQO861?;7E?<&%R7W!L`%A37TEN=&5R;F%L<U]005)?
M0D]/5`!'3$E"0U\R+C(`1TQ)0D-?,BXP`$=,24)#7S(N,P!'3$E"0U\R+C,N
M-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0``````@`"``,``@`"`````@`"````
M`@````(```````````````0``@````(````"`````@`````````````````%
M``8``@````(``@````<````"``(````"``(`!@````0```````(``@`"``,`
M`@``````!P```````@`"``(````````````(``````````(``@`(``,`"``#
M``(``@`)``````````$``0`!``$``0`!``$``0`!``$``0`!``$``0````$`
M`0`!``$``0`!`````0`!``$``0````$``0`!``$``0`!``$``@```K(````0
M````,`UI:1(````&```%M@```!`-:6D0`````P``!<````````$`!@```P$`
M```0``````UI:1,````)```%R@```!`-:6D2````"```!;8````0"6D9=```
M``<```74````$`EI&7(````%```%X````!`-:6D4````!```!>P````0#6EI
M$`````(```7``````!``-`(``$D&`````!``-`8``$D$`````!``-3(``$D&
M`````!``-5H``$D$`````!``.FX``$D&`````!``.KH``$D$`````!``.MH`
M`$D&`````!``.MX``$D$`````!``.YX``$D&`````!``.Z8``$D$`````!``
M._X``$D$`````!``/$H``$D$`````!`!S_```"@4`````!`!T6```&(3````
M`!`!T`````$5`````!`!T`0```(5`````!`!T`@```,5`````!`!T`P```45
M`````!`!T!````85`````!`!T!0```<5`````!`!T!@```@5`````!`!T!P`
M``D5`````!`!T"````H5`````!`!T"0```L5`````!`!T"@``%,5`````!`!
MT"P```P5`````!`!T#````T5`````!`!T#0```X5`````!`!T#@```\5````
M`!`!T#P``!`5`````!`!T$```!$5`````!`!T$0``!(5`````!`!T$@``!,5
M`````!`!T$P``!05`````!`!T%```!45`````!`!T%0``!85`````!`!T%@`
M`!<5`````!`!T%P``!@5`````!`!T&```!D5`````!`!T&0``!H5`````!`!
MT&@``!L5`````!`!T&P``!P5`````!`!T'```!T5`````!`!T'0``!X5````
M`!`!T'@``!\5`````!`!T'P``"`5`````!`!T(```"$5`````!`!T(0``"(5
M`````!`!T(@``",5`````!`!T(P``"05`````!`!T)```"45`````!`!T)0`
M`"85`````!`!T)@``"<5`````!`!T)P``"@5`````!`!T*```"D5`````!`!
MT*0``"H5`````!`!T*@``"L5`````!`!T*P``"P5`````!`!T+```"T5````
M`!`!T+0``"X5`````!`!T+@``"\5`````!`!T+P``#`5`````!`!T,```#$5
M`````!`!T,0``#(5`````!`!T,@``#,5`````!`!T,P``#05`````!`!T-``
M`#45`````!`!T-0``&X5`````!`!T-@``#85`````!`!T-P``#<5`````!`!
MT.```#@5`````!`!T.0``#D5`````!`!T.@``#H5`````!`!T.P``#L5````
M`!`!T/```#P5`````!`!T/0``#T5`````!`!T/@``#X5`````!`!T/P``$`5
M`````!`!T0```&D5`````!`!T00``$(5`````!`!T0@``$,5`````!`!T0P`
M`$05`````!`!T1```$45`````!`!T10``$85`````!`!T1@``$<5`````!`!
MT1P``$@5`````!`!T2```$H5`````!`!T20``$L5`````!`!T2@``$P5````
M`!`!T2P``$T5`````!`!T3```$X5`````!`!T30``$\5`````!`!T3@``%`5
M`````!`!T3P``%$5`````!`!T4```%(5`````)0A__!\"`*FD`$`%)/!``A"
MGP`%?\@"IC_>``([WKGX@![__"^```!!G@`(2`!%S4@``W%(`$+I@`$`%'P(
M`Z:#P0`(."$`$$Z``"````````````````"4(?_0?`@"II!A`!PX80`<D($`
M&#B!`!B0H0`4.*$`%)`!`#23X0`LD\$`*$@`1:4\@!``/&`0`#B$7,`X8UUP
M?(4C>$@`06TX8```2`!$58OC```OGP``0)X`-$@`1)4](!`"+X,``)!IX8Q!
MG@'L2`!#H3A@``!(`$>I@&,``$@`1T%(`$-MF^,``#A@``!(`$>1@&,``$@`
M1RE(`$;EB`,``'QI&W@X8```8````I@)``!(`$=M@&,``$@`1P5(`$;!/2`0
M`(@#``#`"6"\/2`0`&````&8`P``/`!#,)`!``B`80`<.&,`!9!A``S)H0`(
M_:T`*,@)8,`](!``_:T`*L@)8,C_C0``09T!-%1C$#H_X!`"2`!$.8%!`!@]
M8!``.__1?("A`!Q\:1MX@`H``"^%``&0?Q`(D`,``#@+8U`]8!``D`,`!#@+
M8\0]8!``D`,`"#@+8U20`P`,.```!)`?$`1`G0`<.`7__SEC``Q\"0.FA`H`
M!)0+``1"`/_X.*4``SE@``"`?Q`05*`0.CR`$`!]:0$N.(0]D'TF2W@XX```
M2`!%.7Q^&WE!@@!,@'\0$$@`0LD\8!``.&-AH$S&,8)(`!SQ+X,``$&>`#R`
M?Q`02`!"24@`1-6``0`T?\/S>(/!`"A\"`.F@^$`+#@A`#!.@``@@'\0$$@`
M15%\?AMX2___K(!_$`PO@P``09X`#$@`/FE+__^X/&`0`#AC83Q,QC&"2``<
MC2^#``"0?Q`,09[_G$O__]P\8!``/(`0`CAC8H@XA-%@3,8Q@D@`0]TX8``!
M2`!#57PI"WA4(0`V.````)0A__!\"`.FD`$``#T`$`"%J&`X2`!#<)0A_^!\
M"`*FDX$`$#^`$`*0`0`DB!S1=).A`!0O@```D\$`&)/A`!Q`G@!@/Z`0`C_`
M$`([O<[P.][.]#_@$`)_W?!0@3_1>'_>%G`[WO__?XGP0$"<`"P[_]%X.2D`
M`54@$#J1/P``?!T`+GP)`Z9.@`0A@3\``'^)\$!!G/_@.````9@<T72``0`D
M@X$`$'P(`Z:#H0`4@\$`&(/A`!PX(0`@3H``()0A__!\"`*FD`$`%(`!`!0X
M(0`0?`@#IDZ``"!\"`*FE"'_\#Q@$`*0`0`4@`/.^#ACSO@O@```09X`'#T@
M```X"0``+X```$&>``Q\"0.F3H`$(8`!`!0X(0`0?`@#IDZ``""4(?_P?`@"
MII`!`!2``0`4."$`$'P(`Z9.@``@E"'\4'QL&W@Y8P`X.&``"#@```!\:0.F
MD<$#:#DA`."1X0-LD@$#<)(A`W2200-XDF$#?)*!`X"2H0.$DL$#B)+A`XR3
M`0.0DR$#E)-!`YB380.<DX$#H).A`Z23P0.HD^$#K($+``"!2P`$.6L`")$)
M``20"0``D`D`")%)``PY*0`00@#_X#B``$`Y(0%`?(D#ICB@```Y*0`(@0G_
MV(%)_]R!:0``@`D`!(#)_ZA]"UIX@.G_K'U``GB!"?^8?,M:>(%)_YQ\X`)X
M?0M:>)"I`!A]0`)X56L(/%0`"#Y\`%MXD`D`'$(`_["!00#@/*!:@CO```"!
M80#D8*5YF3M```"`S``@?U+3>(#L`"2#@0#H@Z$`['UK.!1]2C$4@0P`&'U&
M4WB!+``<?.LJ%(*,``Q\"S@0?``!$(*L``!_O4@4?YQ!%((!`/!6B?`^@B$`
M]%:J*#1\``#0@LP`"'S`,A2"C``0@JP`%%;+\`)_EN-X@NP`!'T[6WA^,:@4
M?A"A%(!L`!2"K``,5NLH/H,,`!Q]?U-X?OTJ%'QKJ#B#+``0?>?X%'W&\11_
M`*AX@JP``(/,``1]/;@0?2E)$'_Q*A2`@0#\?TJH.'\HJ'A_9_`X@X$`^'QF
M\'A\$UMX@&$!!'U40WA6J_`"5\KP/GTI`-!\#YH4?5E;>'^D*A1]<?@0?6M9
M$'[)LA1\]3-X?V@`>'ZUN!1^E+$4?`?(.(*!`0!]1.@0?4I1$("!`0Q4"2@^
M?AZ#>'UK`-!]-4H45!?P/GZC*A1]$SMX?\OR%'U*`-!]*+@X.P```'UCJ!!]
M:UD0?_^8%'_>D12`80$452\H/G^*XA1_*DAX?!]Z%%4G\#Y__=@4?]S1%(-!
M`0A_9"H4?5%#>'\0PWA]:P#0?C'X%'X0\11\"#@X.L```'U$V!!]2E$0@($!
M''Z+HA14"2@^?NL`>'TQ2A1^=<@4?E3!%(,!`1!_(RH45!_P/GU]0WA^W+-X
M?4H`T'YSZ!1^4N$4?2CX.'UCR!!]:UD0@&$!)%4Q*#XXP```?TK2%'SJ2'A\
M$XH4?WNX%']:L115/?`^@L$!&'[D*A1]54-X?-0S>'UK`-!^M=@4?I31%'P(
MZ#A]1+@0?4I1$'\+PA2`@0$L?^L`>#O```!4"2@^?35*%'SGR!1\QL$4@P$!
M('\C*A14&_`^?7-#>'_2\WA]2@#0?G,X%'Y2,11]*-@X?6/($'UK61"`80$T
M53$H/G[*LA0[@```?ZI(>'P3BA1__[@4?]ZQ%%4G\#Z"P0$H?N0J%'U50WA_
ME.-X?6L`T'ZU^!1^E/$4?`@X.'U$N!!]2E$0?PO"%("!`3Q_:P!X.T```%0)
M*#Y]-4H4?[W(%'^<P12#`0$P?R,J%%0?\#Y]<T-X?U+3>'U*`-!^<^@4?E+A
M%'TH^#A]8\@0?6M9$(!A`415,2@^?LJR%#C```!\ZDAX?!.*%'][N!1_6K$4
M53WP/H+!`3A^Y"H4?55#>'S4,WA]:P#0?K78%'Z4T11\".@X?42X$'U*41!_
M"\(4@($!3'_K`'@[P```5`DH/GTU2A1\Y\@4?,;!%(,!`4!_(RH45!OP/GUS
M0WA_TO-X?4H`T'YS.!1^4C$4?2C8.'UCR!!]:UD0@&$!5%4Q*#Y^RK(4.X``
M`'^J2'A\$XH4?_^X%'_>L115)_`^@L$!2'[D*A1]54-X?Y3C>'UK`-!^M?@4
M?I3Q%'P(.#A]1+@0?4I1$'\+PA2`@0%<?VL`>#M```!4"2@^?35*%'^]R!1_
MG,$4@P$!4'\C*A14'_`^?7-#>']2TWA]2@#0?G/H%'Y2X11]*/@X?6/($'UK
M61"`80%D53$H/G[*LA0XP```?.I(>'P3BA15/?`^?WNX%']:L12"P0%8?N0J
M%'U50WA\U#-X?6L`T'ZUV!1^E-$4?`CH.'U$N!!]2E$0?PO"%("!`6Q_ZP!X
M.\```%0)*#Y]-4H45!OP/GSGR!1\QL$4?7-#>(,!`6!_(RH4?]+S>'U*`-!^
M<S@4?E(Q%'THV#@[@```?6/($'UK61!5,2@^@&$!='[*LA1_JDAX?!.*%'__
MN!1_WK$452?P/H+!`6A^Y"H4?55#>'^4XWA]:P#0?K7X%'Z4\12"@0%X?`@X
M.#M```!]1+@0?4I1$("!`7Q4"2@^?PO"%']K`'A]-4H4?SGH%'\8X12#@0%P
M?Z,J%%0?\#Y]<T-X?U+3>'U*`-!^<\@4?E+!%'SK2'B"00&`?0/H$'T(01"`
M80&$534H/CC```!^RK(4?2KX.'P3JA1^]]@4?M;1%'ZD*A2#00&,53GP/GUQ
M4WA\T#-X?0@`T'XQN!1^$+$4?^H`>'UDJ!!]:UD05!,H/H"!`8A_B.(4.\``
M`'P(R#@_8&[9?3&:%&-[ZZ%\Y^@4?,;A%%07\#Y]3T-X?\[S>($!`91]:P#0
M?F/:%'WO.!1]SC$4?2JX.'Z+HA0[````?RM(>%4E*#Y5)_`^?7U3>'TO*A1\
M`Y@0?``!$'\<PWB`80&<?_^H%'_>H11\NMH4?__H%'_>X115,2@^@\$!D'P`
M`-`XP```?.JZ>'UZ*!!]:UD0?D"2%(-!`@Q\'XH4.L```'_HVA1_.9@4?QB1
M%%4]\#Y\U+)X?55*>'UK`-!]*/@0?2E)$'ZUR!1^E,$4@0$!I'^J.G@[@```
M5!$H/GR+(A1]*0#0?O<H%'[6(12`@0&8?*/:%%09\#Y]=8H4?Y(R>'U3`GA_
MR?(4?G.X%'Y2L11__S@4?]XQ%(#!`:!\Z-H4?RKJ>#L```!\`R@0?``!$%5Q
M*#Z`80&L57?P/GTSBA1_%.)X?55:>'P``-!]:#@0?6M9$'ZU^!1^E/$4@0$!
MM'[JRG@ZP```53$H/GR`(A1]:P#0?[TH%'^<(12`@0&H?*/:%%4_\#Y\%8H4
M?M+">'U32GA\RS(4?G/H%'Y2X11_.3@4?Q@Q%(#!`;!\Z-H4?^JZ>#O```!]
M(R@0?2E)$%01*#Z`80&\5!WP/GUSBA1_U+)X?54">'TI`-!\"#@0?``!$'ZU
MR!1^E,$4@0$!Q'^J^G@[@```57$H/GR)(A1\``#0?O<H%'[6(12`@0&X?*/:
M%%5Y\#Y]-8H4?Y+R>'U36GA\P#(4?G.X%'Y2L11__S@4?]XQ%(#!`<!\Z-H4
M?RKJ>#L```!]8R@0?6M9$%4Q*#Z`80',53?P/GP3BA1_%.)X?55*>'UK`-!]
M*#@0?2E)$'ZU^!1^E/$4@0$!U'[JRG@ZP```5!$H/GR+(A1]*0#0?[TH%'^<
M(12`@0'(?*/:%%0?\#Y]=8H4?M+">'U3`GA\R3(4?G/H%'Y2X11_.3@4?Q@Q
M%(#!`=!\Z-H4?^JZ>#O```!\`R@0?``!$%5Q*#Z`80'<57WP/GTSBA1_U+)X
M?55:>'P``-!]:#@0?6M9$'ZUR!1^E,$4@0$!Y'^J^G@[@```53$H/GR`(A1]
M:P#0?O<H%'[6(12`@0'8?*/:%%4Y\#Y\%8H4?Y+R>'U32GA\RS(4?G.X%'Y2
ML11_*NIX.P```'TC*!!]*4D0@&$![%01*#Y__S@4?]XQ%'SHVA2`P0'@5!?P
M/G\4XGA]<XH4?54">'TI`-!\"#@0?``!$'__J!1_WJ$4@0$!](/!`>@ZP```
M?NK*>%5Q*#Y\B2(4?```T%5U\#Y]/XH4?M+">'_CVA1]4UIX?[TH%'^<(11\
MP#(4?[V8%'^<D10Z@```?JJZ>'UC^!!]:UD0@&$!_%4Q*#Y_.3@4?Q@Q%'SH
MVA2`P0'P53/P/GZ$LGA\'8H4?45*>'UK`-!]*#@0?2E)$#I```"!`0($?SDH
M%'\8(11^:JIX5`7P/E01*#Y_R_(4?2D`T'UYBA0X@```?S^X%'\>L11^7*)X
M@\$!^'_CVA1]70)X?,DR%'RJFGA_O<@4?YS!%'SGJ!1\QJ$4?`/X$'P``1!5
M<2@^?):2>'U76GA]/8H4?O<X%'[6,12`P0(`57GP/GSHVA1\``#0?R,J>#L`
M``!5*R@^?\#R%'P(.!!\``$0?QPB>'T76A1\?4IX?7^8%'U>D11\``#053_P
M/G^]6!1_G%$4.\```%4+*#Y\P#(4.2```'_@RGA\YR@4?,8A%'_*PGB`H0(4
MD2$`&'T]6A1\"T)X@($"'#K```!_IU@4?X91%'UZVA2!00((?!I8$'P``1""
MX0(D?```T)+!`)A5!_`^?4!2%(+!`B!_.5@4?QA1%#C```!\X/IX52LH/GS*
M\GA]'5H4?`M*>'^Y6!1_F%$4?67:%(%!`A!\!5@0?``!$'P``-!5.?`^?4!2
M%'__6!1_WE$4?R`Z>#L```!5"R@^.4```'T]6A2100"0?`M">'\*,G@[0```
M?[]8%'^>411]9-H4@4$"&'P$6!!\``$0DT$`B'P``-!]0%(451_P/GRK.!1\
MBC$452LH/GS]6A0[P```?^#*>#^@CQL[@```8[V\W'_*PGA\"TIX.H```']E
M6!1_1%$4?7VX%'U<L12#00*8DH$`H'\Y6!1_&%$4@4$"B%4E\#Z!80*,?*#[
M>#B```!\H_@X?3U8%'T<412!00*0?.``.(%A`I0Z@```D0$`R#I````YP```
M?OU8%'[<412!`0(H5.LH/I$A`,Q\VUH4@2$"+#H```"#80*<?7U(%'U<0122
MP0#05.GP/I+A`-1^_=@4?MS1%']K^!1_2O$4@^$"-'R*\#B#P0(P?`L;>'T@
M*WB2P0#8?SE8%'\84114RR@^DN$`W'SY6A2#`0*`?7WX%'U<\10Y````@R$"
MA'TC*#A\P``X.L```#K@``!_ZR@4?\HA%)+!`*A4Q?`^@L$".'T*(#A\"QMX
MDN$`@(+A`CQ_>U@4?UI1%'R@2WA4ZR@^?-M:%#B```!_?<@4?US!%'U]N!1]
M7+$4DT$`P'RC2#A\X``XDV$`Q']K2!1_2D$4@P$"0%3I\#Y\BD`X@R$"1'P+
M&WA]("MX?_]8%'_>4114RR@^?/]:%#D```!]?<@4?5S!%'TC*#A\P``X.\``
M`)/!`'A_ZR@4?\HA%'T*(#A\"QMX?WM8%']:4114ZR@^@T$">%3%\#Y\VUH4
M@V$"?'R@2W@X@```?*-(.'U]V!1]7-$4@T$"2'S@`#B#80),.P```)%!`+@Z
MP```D6$`O'U]V!1]7-$4?VM(%']*011\BD`X?`L;>%3I\#Y__U@4?]Y1%%3+
M*#Z#P0)0?/]:%(/A`E1]("MX.4```#D```!](R@XD4$`<'S``#A]??@4?5SQ
M%'_K*!1_RB$4?0H@.)/!`"A\"QMXD^$`+%3%\#Y_^U@4?]I1%(-!`G!\H$MX
M@V$"='SC`#B#P0)8.(```'U]V!1]7-$4D&$`;'RC2#B180"T5.LH/GS?6A2#
MX0)<.T```)%!`+!]??@4?5SQ%'_K2!1_RD$4D^$`9'R*0#B#X0!LD\$`8'_K
M&WB#P0`H@^$`+'T_6!1]'E$45/_P/E3+*#XXX```?^`K>)#A``A\Z5H4.\``
M`%3H*#Z!(0)D?^,H.)$!``Q\P``X5/OP/H$!`F!]?4@4?5Q!%'TK*!1]"B$4
M?\H@.("!`&1\"QMX@&$`8)$A`"Q4R?`^?6L@%'U*&12`@0`,?2#[>'SF`#B1
M`0`H?6LB%'TJ^#A592@^57GP/I"A`'1_8$MX.0```("A`,!]8``XD,$`8(#!
M`,2`X0)L?(;(%'QEP12`P0)HD4$`;'U].!1]7#$4@,$`L(#A`+1]:_@4?4KQ
M%)!A`,!_8T@XD($`Q'P#&WA\IT@4?(9!%']'0#B080`DD.$`('\@VWB0H0"T
M@,$`)("A`""0@0"P@.$`8'R+,!1\:BD4?0;P.($!`&R0P0`0?.=#>)"!`"20
MX0`4@\$`*(/A`"R`@0`4D&$`((!A`!"`P0`D?7\@%'U>&12`@0!T@.$`U'TK
M(A15)2@^53?P/GUF*A2`P0#0?2,`.%5U\#Y5:"@^D*$`?'_GJ!1_QJ$4D0$`
MA'[@RWB`X0"X?6``.($!`+Q^Z<@X?R78.'P)2WA\92MX?6C8%'U'T11^R,`X
MD0$`.)$A`#R`P0`XD*$`-'Z%L#B`X0`\@R$`M'TK.!1]"C$4?P?0.(-A`#20
MX0`P@P$`L)"A`$"#00`P@&$`R'UYV!1]6-$4@V$`A(,!`,!]"]H4@R$`Q%4`
M*#Z#00!`51/P/GSI`A20`0",?J"[>'T``#A^J;@X?`E+>%3D*#Z1(0!$?FFH
M.%3Q\#Z0@0"4@V$`1'UYV!1]6-$4?,LB%("!`,Q4P"@^5,_P/I`!`)Q^8*MX
M?62X%'U#L11\X``X@J$`W'Y$H#A\"4MX@H$`V)"!`$A]X(MX?A:0.)$A`$Q_
M-9@4?Q21%'W5@#B2H0!8.(```(#A`$B!`0!,DL$`4'UK0!1]2CD4@0$`G'TK
M0A1]ZX@X?2``.%4J*#Y\"UMX?B";>)%!`*1\Q@`X?B"8.)%A`%Q5*?`^?,`#
M>)$A`!Q]-TMX?2-[>)`!`%1^]+MX@T$`4(-A`%2"P0`8?7_8%'U>T12#80"D
M@4$"H'[:<#A\"]H4@6$"I(/!`%A4!?`^@^$`7'S]6!1\W%$4?NMX.()!`K!]
M.?@4?1CQ%'\GB!1_!H$4@,$"J(#A`JQ4'R@^?``8.($!`!A\&UMX?2GZ%)/A
M`*Q\H+MX53_P/H)A`K1_.=@4?QC1%'RKH#B"@0`8?WTX%']<,12"`0*X53<H
M/H(A`KQ]*0`X?(9`.'P9NA1])UMX?OMX%'[:<11_Z2MX@<$"P'[W.!1^UC$4
M@>$"Q%05*#Y4&_`^?`E(.'P7JA2"H0`<.\```'S]F!1\W)$4?^LH.'SGJ!1\
MQJ$4?]@@.'TY6WA_:?MX?F?(%'Y&P11_:_@X?SV(%'\<@12"`0+(.T```((A
M`LQ\"4@X/.#*8CC```!@Y\'65!WP/GRER!1\A,$4?U;P.'TW6WA4%2@^?!.J
M%'[W*!1^UB$4?ZC:>'RG>!1\AG$4.X```('!`M!_BM)X@>$"U%09\#Y\I?@4
M?(3Q%'T+`GB!#``@5`DH/GYE6!1^1%$4?3=*%'RGB!1\AH$4?ROJ>((!`M@[
M````@B$"W'][*!1_6B$4?Q;B>%4_\#Y]=TIX534H/GP3JA1_Z\IX?KNX%'Z:
ML10[P```?N=X%'[&<12!P0+@?[VX%'^<L12!X0+D?\3">%0;\#Y]90)X5`DH
M/GY]*!1^7"$4?35*%'RGB!1\AH$4?VOZ>((!`N@[0```@B$"['\Y*!1_&"$4
M?U;R>%4]\#Y]=TIX534H/GP3JA1_J]IX?KFX%'Z8L10[@```?N=X%'[&<12!
MP0+P?_^X%'_>L12!X0+T?X32>%09\#Y]90)X5`DH/GY_*!1^7B$4?35*%'RG
MB!1\AH$4?ROJ>((!`O@[````@B$"_'][*!1_6B$4?Q;B>%4_\#Y]=TIX534H
M/GP3JA1_Z\IX?KNX%'Z:L10[P```?N=X%'[&<12!P0,`?[VX%'^<L12!X0,$
M?\3">%0;\#Y]90)X5`DH/GY]*!1^7"$4?35*%'RGB!1\AH$4?VOZ>((!`P@[
M0```@B$##'\Y*!1_&"$4?U;R>%4]\#Y]=TIX534H/GP3JA1_J]IX?KFX%'Z8
ML10[@```?N=X%'[&<12!P0,0?_^X%'_>L12!X0,4?X32>%09\#Y]90)X5`DH
M/GY_*!1^7B$4?35*%'RGB!1\AH$4?ROJ>((!`Q@[````@B$#''][*!1_6B$4
M?Q;B>%4_\#Y]=TIX534H/GP3JA1_Z\IX?KNX%'Z:L10[P```?N=X%'[&<12!
MP0,@?[VX%'^<L12!X0,D?\3">%0;\#Y]90)X5`DH/GY]*!1^7"$4?35*%'RG
MB!1\AH$4?VOZ>((!`R@[0```@B$#+'\Y*!1_&"$4?U;R>%4]\#Y]=TIX534H
M/GP3JA1_J]IX?KFX%'Z8L10[@```?N=X%'[&<12!P0,P?_^X%'_>L12!X0,T
M?X32>%09\#Y]90)X5`DH/GY_*!1^7B$4?35*%'RGB!1\AH$4?ROJ>((!`S@[
M````@B$#/%4_\#Y_>R@4?UHA%'\6XGA]=TIX534H/GP3JA0[P```?KNX%'Z:
ML11_Z\IX?N=X%'[&<12!P0-`?[VX%'^<L12!X0-$?\3">%0;\#Y]90)X5`DH
M/GY]*!1^7"$4?35*%'RGB!1\AH$4?VOZ>((!`U`[0```@B$#5%4]\#Y_.2@4
M?Q@A%']6\GA]=TIX534H/GP3JA0[@```?KFX%'Z8L11_J]IX@H$#6'[G>!1^
MQG$4?O?X%'[6\11_A-)X?64">%0)*#Y^=R@4?E8A%(+!`TA4&?`^@N$#3'TU
M2A0[````?ROJ>'RGN!1\AK$4534H/GP3JA2"H0-<?Q[B>%4W\#Y]?TIX?WLH
M%']:(11^Z\IX.L```'][^!1_6O$45`DH/G_GB!1_QH$4?3M*%'__Z!1_WN$4
M?L3">'UE`GA4'?`^?W\H%']>(115*R@^@TP`#'R[6A1_H+IX?6>H%'U&H10[
M@```.(```'SKR!1\RL$4@PP``'^>LGB#+``$?!]*>%2K*#Y4@"@T?_\X%'_>
M,12#S``8?7L#>'U_VA0Y0```@VP`%'UKR!1]2L$4@RP`"%4G\#Z#[``<.,``
M`'RET!1\A,D4@2P`)#@```"#3``0?[WX%'^<\11^]T@4?M9!%)`,``!\Y]@4
M?,;1%)%L``20#``(D*P`#)`,`!"0[``4D`P`&).L`!R0#``@DNP`)('!`VB!
MX0-L@@$#<((A`W2"00-X@F$#?(*!`X""H0.$@L$#B(+A`XR#`0.0@R$#E(-!
M`YB#80.<@X$#H(.A`Z2#P0.H@^$#K#@A`[!.@``@E"'_T'P(`J:3@0`@?'P;
M>3A@``"300`8?)HC>)`!`#2380`<DZ$`))/!`"B3X0`L08(`F#T@``"#:0``
M+YL``$&>`(B('```.Z```"^```!!G@`P+X``/4&>`"A_B>-X?YWC>(P)``$[
MO0`!+X```"\``#U!G@`(0)K_['^\Z%"#^P``.&```"^?``!!G@`\?W[;>'_C
M^WA_A.-X?Z7K>$@`*74O@P``0)X`$'P?Z*XO@``]09X`/(?^``0OGP``0)[_
MU#A@``"``0`T@T$`&'P(`Z:#80`<@X$`((.A`"2#P0`H@^$`+#@A`#!.@``@
M?]OP4#A]``%_WA9P?'\:%)/:``"``0`T@T$`&'P(`Z:#80`<@X$`((.A`"2#
MP0`H@^$`+#@A`#!.@``@E"'_X'P(`J8X@0`<D`$`)$S&,8)+__[!@`$`)#@A
M`"!\"`.F3H``()0A_]!\"`*FD`$`-)/!`"@_P```D^$`+'Q_&WA_X_MX.($`
M'$S&,8)+__Z%+X,``$&>`%"``0`<@7X``%0`$#I]*P(4@4D`!"^*``!]2P$N
M0;[_S#DI``2$"0`$+X```)`)__Q`GO_T?^/[>#B!`!Q,QC&"2__^.2^#``!`
MGO^X@`$`-(/!`"A\"`.F@^$`+#@A`#!.@``@E"'_X'P(`J8X8```D`$`))/!
M`!B3X0`<2``HD8!C``!(`"@I2``DQ8$C```X8```@^D`!$@`*'6`8P``2``H
M#4@`)$F+PP``.&```$@`*%V`8P``5]X&?D@`)_%(`"1=@2,``#A@``"`"0`0
M5`"$,'_``WBP'P`"2``H,8!C``!(`"?)2``D98$C```X8```@^D`!$@`*!6`
M8P``2``GK3R`$``XH```.(1B:$@`)>V0?P`<.&```$@`)_&`8P``2``GB4@`
M)"6!(P``.&```(/I``1(`"?5@&,``$@`)VU(`"<Y@`,``#A@``"0'P`@2``G
MN8!C``!(`"=12``C[8$C```X8```@^D`!$@`)YV`8P``2``G-4@`)Z$X````
M@2,``"^)``!!G@`@.&```$@`)WF`8P``2``G$4@`)WV!(P``@`D`;)`?`"0X
M8```.^```$@`)U6`8P``2``F[4@`(XF!(P``.&```($I``23Z0`H2``G-8!C
M``!(`";-2``C:8$C```X8```@2D`!)/I`!A(`"<5@&,``$@`)JU(`"-)@2,`
M`#A@``"#Z0`$2``F^8!C``!(`":12``CG8`#``"0'P`L@`$`)(/!`!A\"`.F
M@^$`'#@A`"!.@``@E"'_8'P(`J:3X0"<?'\;>9`!`*2380",DX$`D).A`)23
MP0"808(`$(@?```O@```0)X`*(`!`*2#80",?`@#IH.!`)"#H0"4@\$`F(/A
M`)PX(0"@3H``($@`)E%\?AMY0:+_U#^`$``[G&#0?\/S>$@`)9E\:1MY?^/[
M>#MI`!-!@@"<B`D`$R^``"Y!G@#$2``C^7Q]&WA_8]MX2``C[7Q]&A0X8P`"
M2``C<7^&XWA_Y_MX?'T;>']HVW@X@``!.*#__TS&,8)(`"0!?Z3K>#BA`!@X
M8``#2``E@2^#__]_H^MX09X`%(`!`"A4``0F+X!``$&>`(!(`"(A?Z/K>$@`
M(3E_P_-X2``E`7QI&WE_X_MX.VD`$T""_VQ_P_-X2``E>7_C^WA(`"%A@`$`
MI(-A`(Q\"`.F@X$`D(.A`)2#P0"8@^$`G#@A`*!.@``@B`D`%"^```!!GO\4
M+X``+D"^_S"("0`5+X```$&>_P!+__\@2__^C4O__X24(?_@?`@"II/A`!Q\
M?QMX.&```)`!`"23P0`82``E,3O```"`8P``2``DQ4@`('%_Y/MX?&4;>#A@
M``-(`"3!+X,``$&>`""``0`D?\/S>(/!`!A\"`.F@^$`'#@A`"!.@``@2``D
MZ8!C``!(`"2!2``@+8`#`!!4``0F+X!``$&>`"PX8```2``DQ8!C``!(`"1=
M2``@"8$C`!!5*00F;2#__R^`H`!`GO^@?^/[>#B```)(`"-Y@`$`)'Q^`#2#
MX0`<?`@#IE?>V7Y_P_-X@\$`&#@A`"!.@``@E"'_P'P(`J:3@0`PDZ$`-)/!
M`#B3X0`\?'\;>)`!`$23`0`@DR$`))-!`"B380`LB`0``&@=`#TCO0``?Z0!
ME'^CZWA(`"'M.($`''Q\&WA_X_MX3,8Q@DO_^85\?AMY08(!3$@`(<T[WO__
M.3W__W^<&$!`G0$4@T$`'#]@``!76A`ZB!\``#D@```O@```09X`-"^``#U!
MG@`L?^O[>'_I^WA(```(09H`&(P+``$Y*0`!+X```"\``#U`GO_L?3](4#A\
M``*#VP``?&-*%$@`(/$X`/__+X,``'Q^T2Y!G@!TB!\``#T@``"!:0``+X``
M`($A`!Q5*1`Z?2M(+I@)``!!G@`P+X``/4&>`"A]*TMX2```"$&:`!R,'P`!
M.2D``2^````O```]G`L``4">_^@X```].[W__Y@)``",'0`!+X```)P)``%`
MGO_T.````'P#`WB``0!$@P$`('P(`Z:#(0`D@T$`*(-A`"R#@0`P@Z$`-(/!
M`#B#X0`\."$`0$Z``"","0`!+X```)P>``%!OO^\C`D``2^```"<'@`!0)[_
MY$O__Z@_8```.(``"(,;```[P```@!@``"^```!!G@`@?PG#>(0)``0[W@`!
M+X```$">__0XG@`"5(00.CT@$`*`"=%\+X```$&>`#Q_`\-X5]H0.D@`'[4X
M`/__+X,``'QY&WB0>P``0;[_1#@>``$Y(```5``0.GTY`2Z3P0`<2__^7#@`
M``%\@R-XD`G1?$@`'XDX`/__?'D;>4&B_Q!7VA`Z?P3#>']%TWA(`!U]DSL`
M`$O__[B4(>_0?`@"ICB@#_^3H1`D?)TC>#B!`!R3P1`H?'X;>#Q@$`"0`1`T
M.&-@V)/A$"R``H_XD`$0'#@```!(`!YE+`,``$"!`)`X`1`@.^/__WT@^A2(
M">_\+X```$&>`'!\?QMX.&$`'#B``"]_Y?MX2``@(2^#``!!G@!<.&```$@`
M(9&`8P``2``A*7_$\W@XH0`<?^;[>$@`()F!(1`<@`*/^'TI`GDX````0((`
M2(`!$#2#H1`D?`@#IH/!$"B#X1`L."$0,$Z``"`OGP``0)[_E#A@``!(`"$Y
M@&,``$@`(-%_Q/-X?Z7K>$@`'<5+__^L2``=/90A__!\"`*F.&```)`!`!1(
M`"$)@&,``$@`(*$\@!``/*`0`#S`$``XA&#H.*5:$#C&801(`!\%@`$`%#@A
M`!!\"`.F3H``()0A__!\"`*F.&```)`!`!1(`"#!@&,``$@`(%E+__^=.&``
M`$@`(*V`8P``2``@13S`$``\@!``.,9B:#R@$``XA&$0.*52>'S',W@Y````
M2``?48`!`!0X(0`0?`@#IDZ``""4(=_0?`@"II/A("P[X```D`$@-)/!("B`
M`H_XD`$@'#@```!(`!UI/,`0`#T`$`!\9QMX.(```3AA`!0XH!`!.,9A*#D(
M831,QC&"2``>(2^#``!!G`!`.&$`%#B!$!@XH!``2``<F7Q^&WE!@``H.'X`
M`4@`'4E\?QMY08(`&#B!$!A_Q?-X2``;=3@```!\'_&N@2$@'(`"C_A]*0)Y
M.````'_C^WA`@@`<@`$@-(/!("A\"`.F@^$@+#@A(#!.@``@2``;R90A__`X
M(0`02___,)0A[[!\"`*F?8``)I.A$$23P1!(?'X;>#Q@$`"3X1!,.&-A/'R?
M(WB1@1`DD`$05)+!$"B2X1`LDP$0,),A$#2301`XDV$0/).!$$"``H_XD`$0
M'#@```!,QC&"2__UU3B``"]\?1MX?\/S>$@`',TO@P``09X`<#Q@$`!_Q/-X
M.&-A2$S&,8)+__JA@2$0'(`"C_A]*0)Y.````'_#\WA`@@&X@`$05(&!$"1\
M"`.F@L$0*(+A$"Q]@($@@P$0,(,A$#2#01`X@V$0/(.!$$"#H1!$@\$02(/A
M$$PX(1!03H``('_#\W@_@!``2``<;3N<85A\>QMX?X3C>'_C^WA(`!V)?'8;
M>4&B_W`N'0``/R`0`#]`$``ZX```/P`0`#LY85P[6F%D8O>``#O@``"(%@``
M+X```$">``@ZV&$X09(`&'^CZWA^Q+-X2``9;2^#``!!G@"T?L.S>$@`&_U]
M-AH4B`G__R^``"]`G@`8G^G__SAC__^("?__+X``+T&>__`X8P`!?&/:%"^#
M#_]!O?[H.(```3B@$`!_)LMX?L>S>'](TWA_R?-X.&$`'$S&,8)(`!OE.&``
M`$@`'=V`8P``2``==4@`&2$X@0`<?&4;>#A@``-(`!U1+X,``$">`"1(`!VU
M@&,``$@`'4U(`!CY@`,`$%0`!"9_@+@`09X`(#A@``!_A.-X2``<?2^#``!\
M=AMX0)[_&$O__EPX80`<.(```4@`'%$O@P``0)[_U#Q@$``X@0`<.&-A2$S&
M,8)+__CE.&$`'$@`&YU\?AMX2__^.$@`&6&4(?_PB`,``"^```!!G@`\.2,`
M`7QK&WA(```4C`L``3DI``$O@```09X`("^``"]`GO_LC`L``7TC2W@Y*0`!
M+X```$">_^@X(0`03H``()0A_^!\"`*FD\$`&'Q^&WF0`0`DD^$`'$&"`.2(
M'@``+X```$&>`-A(`!J%.&/__WR^&A1_'BA`?X7P`$"8`#A\'ABN+X``+T">
M`.1\'BA0?*DK>'P)`Z9(```0C`G__R^``"]`G@#(.*7__W^%\`!"`/_L09X`
M^#@%__]\J2MX?YX`0'P>*%!\"0.F09T!("^>__]!G@$8.*7__T)``!","?__
M+X``+T&>__!\OBA0.&```#@%``(K@!``09T`*#_@$`)_Q/-X.__1?#BE``$[
M_P`$.,`0`'_C^WA(`!K!?^/[>(`!`"2#P0`8?`@#IH/A`!PX(0`@3H``(#A@
M``)(`!D]+`,``$&B_]PX`"X`L`,``(`!`"2#P0`8?`@#IH/A`!PX(0`@3H``
M(#@%__]\J2MX?YX`0'P>*%!\"0.F09T`>"^>__]`O@`42```;(P)__\O@``O
M09X`##BE__]"`/_P?X7P`$O__PR(!0``+X``+T&>`!0\8!``.&-A9$@`&;U+
M__]@.&```D@`&+%\:1MY.&```$&B_TPX`"X`?2-+>+`)``!+__\\.````7P)
M`Z9+__[D.````7P)`Z9+__^<E"'_L'P(`J8\@!``.*``(CB$8$R3@0!`.&$`
M&#^`$`"3H0!$/Z`0`#N<8;B3P0!(.[UA/#_`$`"3X0!,/^`0`#O>8:R0`0!4
M._]AD(`"C_B0`0`\.````$@`%F$\8!``.&-A:$S&,8)+__&!/&`0`#AC871,
MQC&"2__Q<3Q@$``X8V%\3,8Q@DO_\6$\8!``.&-AB$S&,8)+__%1?^/[>$S&
M,8)+__%%/&`0`#AC8:!,QC&"2__Q-7^CZWA,QC&"2__Q*7_#\WA,QC&"2__Q
M'7^#XWA,QC&"2__Q$3Q@$``X8V'$3,8Q@DO_\0$\8!``.&-A2$S&,8)+__#Q
M/&`0`#AC8=!,QC&"2__PX3Q@$``X8V'<3,8Q@DO_\-$\8!``.&-AZ$S&,8)+
M__"9?&0;>4&"`!!_@^-X3,8Q@DO_]7T\8!``.&-A_$S&,8)+__!U?&0;>4&"
M`!0\8!``.&-B$$S&,8)+__55/&`0`#AC8AQ,QC&"2__P37QD&WE!@@!8?Z/K
M>$S&,8)+__4Q/(`0`'_C^W@XA&),3,8Q@DO_]1V!(0`\@`*/^'TI`GDX````
M0((`?(`!`%2#@0!`?`@#IH.A`$2#P0!(@^$`3#@A`%!.@``@/&`0`#AC8BQ,
MQC&"2__OX7QD&WE!@@`4?\/S>$S&,8)+__3%2___E#R`$``X80`I.(1B0#B@
M``I(`!B=+X,``$">_WA_P_-X.($`,TS&,8)+__252___9$@`%1V4(?_@?`@"
MII/A`!P_X!`"@'_14)`!`"0O@___09X`&(`!`"2#X0`<."$`('P(`Z9.@``@
M/&`0`#AC8:Q,QC&"2__O47QI&WDX8```08(`'(@)```O@```09X`$&@#`#!\
M8P#05&,/_H`!`"20?]%0?`@#IH/A`!PX(0`@3H``()0A__!\"`*FD`$`%$@`
M%)U(`!.I?&D;>3A@``!!@@`(@&D``(`!`!0X(0`0?`@#IDZ``""4(?^P?`@"
MICT@$``Y*6!,DZ$`1'Q]&WB3X0!,D`$`5),A`#2300`XDV$`/).!`$"3P0!(
M@`D`)(#I`"A\'P-X@0D`+(E_``"!20`P+XL``(%I`#2!*0`XD`$`&)#A`!R1
M`0`@D4$`))%A`"B1(0`L09X`?#]@$``_@!``.\$`&#M[85P[G&%82```($@`
M$LDO@P``09X`A(?^``2('P``+X```$&>`$A_X_MX3,8Q@DO_[BU_I.MX?'D;
M>4&"`!"(&0``+X```$"^_\1_X_MX?Z3K>$S&,8)+__+]A_X`!(@?```O@```
M0)[_P(`!`%2#(0`T?`@#IH-!`#B#80`\@X$`0(.A`$2#P0!(@^$`3#@A`%!.
M@``@?Z/K>$@`%.E\>AMX?R/+>$@`%-U\>AH4.&,``D@`%&$X@``!.*#__WQZ
M&WA_9MMX?Z?K>'^(XWA_*<MX3,8Q@D@`%.U_X_MX?T33>$S&,8)+__)M2___
M+#P`__]\+`MX8`!^H#T@$`!\(0%N?`@"ICDI8$R3+/_D?'D;>).,__`_@!``
MD`P`!#N<83R2+/_$?X/C>)),_\B2;/_,DHS_T)*L_]22S/_8DNS_W),,_^"3
M3/_HDVS_[).L__23S/_XD^S__(/I`$R`B0!0@*D`5(#)`%B`Z0!<@0D`8(%)
M`&2!:0!H@`D`;(,)`$"#J0!$@\D`2(+I`#P](0`!@B*/^)(I@1PZ(```DN$`
M/)/A`"23`0!`DZ$`1)/!`$B0@0`HD*$`+)#!`#"0X0`TD0$`.)%!`$R180!0
MD`$`5$S&,8)+_^R%?'\;>4&"`!"('P``+X```$">")1+__U=?'@;>4&""*2+
M^```+Y\``$&>`#1(`!6M?PG#>#E``%^!8P``5_\(/'P+^BYP$P@`0((`")E)
M``"/Z0`!+Y\``$">_^"`80`DB`,``"^```!!G@=D.^```4@``#`ZP```5^D0
M.F+6@2`[_P`!?M8*%'TV2A0]*?__@&E_!(@#```O@```09X',$S&,8)+_^O=
M?'X;>4&B_\A+_^_M+X,``$&>_[Q_P_-X2``3>7QW&WE!@O^L?N.[>#^@$`!(
M`!+5.[UA9'Q^&WA_`\-X2``2Q7_>&A0[W@0$?\/S>$@`$D5\?QMX?\/S>$@`
M$CD\P!``/2`0`#B@__\XQF)8?N>[>'^HZW@Y*6)D?PK#>'Q^&W@X@``!3,8Q
M@D@`$KDX@`'M?\/S>$@`$NT\8!``.&-C>$S&,8)+_^LU+X,``$&>!V2#&0``
M2``2W7QD&WA_`\-X2__TZ7QX&WE!@@=(?P/#>$@`$C$O@P`#?'<;>$"=`#@X
M8__\/(`0`'QX&A0XA&)L2``/<2^#``!`G@`<+Y<`!$&>!KQ^^+H4B!?_^R^`
M`"]!G@:L2__[-2^#``!!G@%(/(`0`#Q@$``XA&),.&-AK#\@$`!,QC&"2__O
MF3]@$`!(`!$A.SEB:#S`$`!\:1MX.(```7_C^W@XH/__.,9BE'_'\WA_J.MX
M?RK+>$S&,8)(`!'1.T```#M[8J1(``!(2``2,8`#```O@``10)X`3$@`$-$[
M6@`!.(```9,A``A\:1MX.*#__W_C^WA_9MMX?\?S>'^HZWA_2M-X3,8Q@D@`
M$8%_X_MX.(`![4@`$;4O@___09[_K'_#\WA(``[5?X/C>'_D^WA,QC&"2__N
MY7_C^WA+__L)/,$``7_C^WB`YH$<@,*/^'SG,GDXP```0(('1(%A``"`"P`$
M@BO_Q'P(`Z:"2__(@FO_S(*+_]""J__4@LO_V(+K_]R#"__@@RO_Y(-+_^B#
M:__L@XO_\(.K__2#R__X@^O__'UA6WA.@``@?P/#>#B```!,QC&"2``0L7QY
M&WE!@OZH.*#__SC`_^XXX``"2``/R7\CRW@X@0!8.*``!D@`#=F(`0!8+X``
M`$">`!"(`0!9+X``0T&>!APXP```?R/+>#B@```XX```2``/C3T@9T4Y````
M82DC`9$!`!@\P0`!D2$`'#T@[\TY````82FKB3E````Y8```.````,@!`!@Z
MX```V`:`6)$!`!@Y````D2$`'#T@F+IA*=S^R`$`&-@&@&"1`0`8.0```)$A
M`!P](!`R82E4=L@!`!C8!H!HD0$`&#D```"1(0`</2##TF$IX?#(`0`8V`:`
M<)$!`!B1(0`<R`$`&-@&@'B100`8D6$`',@!`!B0!H#0V`:`@-@&@(@XH```
M?R/+>#B!`%A@I8``2``,X7QX&WE`@0&@/.$``5<(&#B!)X"`?P#^<(#G@(0K
MB0``?0@Z%$&=`"`OB0``/2$``8%)@(B!:8",0)X`('^'0$!`G0`8/B$``8%1
M@(B!<8",,6L``7U*`914"1@X5QL??CY!``%4&A]^?3O;>(!R@-`X````?6O8
M%'U*T122\H"`8`"`D)$2@(0O@P``D4$`&#IA`%A^H0(4D6$`',@!`!C8$H"(
M09X`:"`#`$!_$\-X?Y@``$"=``A\$P-X.,```#B!`%A@QH"0?F6;>'ZA,A1\
M=1H42``,:3SA``&`!X#0?!,"%"^``$"0!X#00)[_`#A@```Y`0!88&.`6'\3
MP%!\8PH4?FB:%$O_S#$OF``_0)T`7#L8_\`ZDP!`5Q+1OGYVFWA60#`R?I0"
M%'[$LW@XH`!`?J.K>#K6`$!(``P!.&```&!C@%A\8PH42__+[7^6H`!`GO_8
M.!(``592,#)4`#`R?Q+`4'YS`A1_!<-X?F2;>#C``$A^HZMX2``-H3TA``$X
MH```DPF`T'\CRW@X@0!88*6``$@`"T5\>!MY08'^:'\CRWA(``_%/4$``3E@
M``"#:H"$86N!('UK"A2#2H",5V7NOC@%``%]*RH4+X``.#@`_X"8"?]P09T#
M$#I@```X@```8G.`6'YS"A1\<RH4(*4`-SAC`#E(``WA/L$``5='1CY72(0^
M5TK"/ICV@,A7:T8^5VF$/ID6@,E78,(^F5:`RCA@``";5H#+8&.`6#XA``&9
M=H#,?&,*%)DV@,V8%H#.FW:`STO_RNT\P0`!@2:`=($&@%R!1H!D53I&/E4[
MA#Z!9H!L50=&/E42A#Z`!H!\51/"/E541CY5580^55;"/IM1@115=T8^57B$
M/IMQ@155><(^52/"/ICQ@0A4!$8^5`6$/II1@0E4!L(^/T`0`)IQ@0J9$8$+
M.V```#M:8HR:D8$,FK&!#9K1@0Z948$/FO&!$)L1@1&;,8$2F7&!$YAQ@1:9
M,8$7F)&!&)BQ@1F8T8$:F!&!&T@``!0Z8```8G.!"'TAFA1\Z=BN.D```%=C
M"#QB4H#<.(```7Y2"A0XH/__?'(:%']&TWA,QC&"2``,=2^;`!,[>P`!0)[_
MP#@````^P0`!.2```)@6@00\P!``82F`W#U`$`!_X_MX.(```3B@__\XQF)\
M?\?S>'^HZWA]*0H4.4IB:$S&,8)(``PE2__ZN(/A`#P[P``!B!\``"^```!`
MO@`T2```?#@```!7R1`Z8`"!(#O>``%\``H4?2!*%#TI__^#Z7\<B!\``"^`
M``!!G@!0?^/[>$O_Z(DO@P``09[_R'_C^WA(``P5?'<;>4"B^*`X````5\D0
M.F``@2`[W@`!?``*%'T@2A0]*?__@^E_'(@?```O@```0)[_N#K@``!+__AL
M@SD`!"^9``!!OOE0?R/+>$@`"S4K@P`#0+WY0#AC__P\@!``?'D:%#B$8G1(
M``AY+X,``$"^^21_.,MX2__Y'$O_]0%_X_MX2``+C7Q_&WA+__GL@QD``$O_
M^+B`80!,B`,``"^```!!G@!0.^```4S&,8)+_^.I+X,``$&>`!!(``M5?'@;
M>4"B]S0Z0```5^D0.F)2@2`[_P`!?E(*%'TR2A0]*?__@&E_+(@#```O@```
M0)[_O#\`$``[&&)02__W.#H@```X@```8C&`6#I```!^,0H48E*`D'QQ*A0@
MI0`_.&,`.4@`"LTX8```8&.`6'QC"A1+_\@9?&&2%#B````XH``X2``*K4O_
M_,R(`0!:+X``04">^>"(`0!;+X``0T">^=2(`0!<+X``2$">^<B(`0!=+X``
M14">^;PXP/_&..```CB@__]_(\MX2``)13B!`%A_(\MX.*``*4@`!U4\P!``
M/4`0`'_C^W@X@``!.*#__SC&8GQ_Q_-X?ZCK>#DA`%@Y2F)H3,8Q@D@`"?5+
M__B(2``(#90A_]!\"`*F.&```)`!`#2300`8DV$`').!`""3H0`DD\$`*)/A
M`"Q(``O!@&,``$@`"UE(``B5.````9@#```\8!``.&-AD$S&,8)+_^(U+`,`
M`$&"`!"(`P``+X``,4&>`G!+__!=.&```#^@$`)(``MY.[W1?(!C``!(``L-
M/(`0`#B@``$XA&*X.,``"T@`"+DL`P``08(`U($]$`0[P```@6,`$"^)``&#
M:P`80)T`L#O@``%(```L@(D`$'^#XWA(``9%@3T0!"^#``!`G@"0._\``3O>
M``%_B?@`0)T`@#A@``!(``L!@&,``$@`"IE_9-MX?\7S>#C```!(``GI?'H;
M>4&"`C"!.@``5^`0.H%]$`B!20`(?XL`+G%(!`!`@O^8.&```$@`"KV`8P``
M2``*58":```XH```.,```D@`!V5\9!MX?X/C>$@`!;F!/1`$+X,``$&>_W@X
M"?__?X#P`$&>`7@X8```2``*>8!C``!(``H1/(`0`#B@``$XA&+`.,``!$@`
M![U\?QMY08(`/#A@``!(``I-@&,``$@`">6!/P`0/*`0`#BE8L2`B0``2``&
MT8$_`!"!*0``@`D`"'0)`$!`@@%,.&```$@`"A6`8P``2``)K3R`$``XH``!
M.(1BS#C```1(``=9?'\;>4&"`#P\8!``.&-A2$S&,8)+_^!Y?'X;>4&"`3PX
M8```2``)T8!C``!(``EI@3\`$'_%\WB`B0``2``&63A@``!(``FQ@&,``$@`
M"4E(``:%.````)@#```X8```2``)E8!C``!(``DM2``%"3@```"0`P``/&`0
M`#AC83Q,QC&"2__@"2^#``"0?1`,09X!"#B``>U(``>=?&8;>4&"`!0OA@`1
M09X`#"^&__]`G@#,@`$`-(-!`!A\"`.F@V$`'(.!`""#H0`D@\$`*(/A`"PX
M(0`P3H``((@#``$O@```0;[]D$O__8@OB0`!0+W^B#O@``$X8```._\``4@`
M"/6`8P``2``(C7]DVWA(``2%@!T0!'^`^`!!G?_<2__^6#A@``!(``C-@&,`
M`$@`"&6!/P`0@(D``$@`!UE+__Z<@3T0!#@)__]_@/``0)[^*$O__YA(``B=
M@&,``$@`"#6!?P`0@3T0"(!K``"`B0``2__F<4O__LB!/1`(/&`0`("]$`PX
M8V,`@(D``$S&,8)(``9Q@'T0"$O_\86!/P`0D'T0#($I``"`"0`(<`L$`$&"
M`$R`:0`0@)T0"$@`!*6!/P`0@7T0"'Q^&WB!*0``@ZL``(`)``AP"`0`08(`
M2("I`!`\8!``?Z3K>#AC8M!_QO-X3,8Q@D@`!@DX8```2``'\8!C``!(``>)
M@3\`$#B@```XP``"@(D``$@`!)5+__^8.&```$@`!\F`8P``2``'88$_`!`X
MH```.,```H")``!(``1M?&4;>$O__YB4(?_@?`@"II/!`!A\?AMXD`$`))/A
M`!Q+_^J=B`,``'Q_&W@O@```09X`/#DC``%\:QMX2```%(P+``$Y*0`!+X``
M`$&>`"`O@``O0)[_[(P+``%]/TMX.2D``2^```!`GO_H2__N12^#``!!G@`P
M+YX``$&>`"B('@``+X```$&>`!P\@!``?^/[>#B$8F1(``(A?Y\8`$&>`!R`
M`0`D@\$`&'P(`Z:#X0`<."$`($Z``""``0`D?\/S>(/A`!Q\"`.F@\$`&#@A
M`"!+_^`,E"'_\'P(`J8X8```D`$`%$@`!L&`8P``2``&63B`__](``.A.&``
M`$@`!JF`8P``2``&03R`$``XH```.(0UN$@`!>&``0`4."$`$'P(`Z9.@``@
M````````````````?`@"ID*?``64(?_P.,```)/!``B0`0`4?\@"IC_>``([
MWO<$@3Z``"^)``!!G@`(@,D``$@``SV``0`4@\$`"#@A`!!\"`.F3H``(```
M``"4(?_0?`@"ID*?``63P0`HDZ$`)),A`!2300`8?+DK>'R:(WB380`<DX$`
M('Q[&WB0`0`TD^$`+'_(`J8_W@`".][VM$O_O66#OH`$@YZ``'^=X%!_G!9Q
M08(`/#N]__P[X```8````&````!@````A!T`!']CVWA_1--X?R7+>#O_``%\
M"0.F3H`$(7^?X$!!G/_@@`$`-(,A`!2#00`8@V$`''P(`Z:#@0`@@Z$`)(/!
M`"B#X0`L."$`,$Z``"!.@``@E"'_\'P(`J:0`0`4D^$`##_@$`([_\[L@!__
M_"^`__]!G@`<.____'P)`Z9.@`0AA!___"^`__]`GO_P@`$`%(/A``PX(0`0
M?`@#IDZ``""4(?_P?`@"II`!`!2``0`4."$`$'P(`Z9.@``@/6`0`H%KT`!]
M:0.F3H`$(#U@$`*!:]`$?6D#IDZ`!"`]8!`"@6O0"'UI`Z9.@`0@/6`0`H%K
MT`Q]:0.F3H`$(#U@$`*!:]`0?6D#IDZ`!"`]8!`"@6O0%'UI`Z9.@`0@/6`0
M`H%KT!A]:0.F3H`$(#U@$`*!:]`<?6D#IDZ`!"`]8!`"@6O0('UI`Z9.@`0@
M/6`0`H%KT"1]:0.F3H`$(#U@$`*!:]`H?6D#IDZ`!"`]8!`"@6O0+'UI`Z9.
M@`0@/6`0`H%KT#!]:0.F3H`$(#U@$`*!:]`T?6D#IDZ`!"`]8!`"@6O0.'UI
M`Z9.@`0@/6`0`H%KT#Q]:0.F3H`$(#U@$`*!:]!`?6D#IDZ`!"`]8!`"@6O0
M1'UI`Z9.@`0@/6`0`H%KT$A]:0.F3H`$(#U@$`*!:]!,?6D#IDZ`!"`]8!`"
M@6O04'UI`Z9.@`0@/6`0`H%KT%1]:0.F3H`$(#U@$`*!:]!8?6D#IDZ`!"`]
M8!`"@6O07'UI`Z9.@`0@/6`0`H%KT&!]:0.F3H`$(#U@$`*!:]!D?6D#IDZ`
M!"`]8!`"@6O0:'UI`Z9.@`0@/6`0`H%KT&Q]:0.F3H`$(#U@$`*!:]!P?6D#
MIDZ`!"`]8!`"@6O0='UI`Z9.@`0@/6`0`H%KT'A]:0.F3H`$(#U@$`*!:]!\
M?6D#IDZ`!"`]8!`"@6O0@'UI`Z9.@`0@/6`0`H%KT(1]:0.F3H`$(#U@$`*!
M:]"(?6D#IDZ`!"`]8!`"@6O0C'UI`Z9.@`0@/6`0`H%KT)!]:0.F3H`$(#U@
M$`*!:]"4?6D#IDZ`!"`]8!`"@6O0F'UI`Z9.@`0@/6`0`H%KT)Q]:0.F3H`$
M(#U@$`*!:]"@?6D#IDZ`!"`]8!`"@6O0I'UI`Z9.@`0@/6`0`H%KT*A]:0.F
M3H`$(#U@$`*!:]"L?6D#IDZ`!"`]8!`"@6O0L'UI`Z9.@`0@/6`0`H%KT+1]
M:0.F3H`$(#U@$`*!:]"X?6D#IDZ`!"`]8!`"@6O0O'UI`Z9.@`0@/6`0`H%K
MT,!]:0.F3H`$(#U@$`*!:]#$?6D#IDZ`!"`]8!`"@6O0R'UI`Z9.@`0@/6`0
M`H%KT,Q]:0.F3H`$(#U@$`*!:]#0?6D#IDZ`!"`]8!`"@6O0U'UI`Z9.@`0@
M/6`0`H%KT-A]:0.F3H`$(#U@$`*!:]#<?6D#IDZ`!"`]8!`"@6O0X'UI`Z9.
M@`0@/6`0`H%KT.1]:0.F3H`$(#U@$`*!:]#H?6D#IDZ`!"`]8!`"@6O0['UI
M`Z9.@`0@/6`0`H%KT/!]:0.F3H`$(#U@$`*!:]#T?6D#IDZ`!"`]8!`"@6O0
M^'UI`Z9.@`0@/6`0`H%KT/Q]:0.F3H`$(#U@$`*!:]$`?6D#IDZ`!"`]8!`"
M@6O1!'UI`Z9.@`0@/6`0`H%KT0A]:0.F3H`$(#U@$`*!:]$,?6D#IDZ`!"`]
M8!`"@6O1$'UI`Z9.@`0@/6`0`H%KT11]:0.F3H`$(#U@$`*!:]$8?6D#IDZ`
M!"`]8!`"@6O1''UI`Z9.@`0@/6`0`H%KT2!]:0.F3H`$(#U@$`*!:]$D?6D#
MIDZ`!"`]8!`"@6O1*'UI`Z9.@`0@/6`0`H%KT2Q]:0.F3H`$(#U@$`*!:]$P
M?6D#IDZ`!"`]8!`"@6O1-'UI`Z9.@`0@/6`0`H%KT3A]:0.F3H`$(#U@$`*!
M:]$\?6D#IDZ`!"`]8!`"@6O10'UI`Z9.@`0@2``!0$@``3Q(``$X2``!-$@`
M`3!(``$L2``!*$@``21(``$@2``!'$@``1A(``$42``!$$@``0Q(``$(2``!
M!$@``0!(``#\2```^$@``/1(``#P2```[$@``.A(``#D2```X$@``-Q(``#8
M2```U$@``-!(``#,2```R$@``,1(``#`2```O$@``+A(``"T2```L$@``*Q(
M``"H2```I$@``*!(``"<2```F$@``)1(``"02```C$@``(A(``"$2```@$@`
M`'Q(``!X2```=$@``'!(``!L2```:$@``&1(``!@2```7$@``%A(``!42```
M4$@``$Q(``!(2```1$@``$!(```\2```.$@``#1(```P2```+$@``"A(```D
M8````&````!@````8````&````!@````8````&`````]@!`"/6OP`(`,S_@Y
M:Z&`?`D#IGP+6A2!C,_\?6!:%$Z`!"!@````8````&````!@````8````&``
M``!@````E"'_\'P(`J:0`0`4D\$`"$*?``5_R`*F/]X``3O>;^!+_[BE@`$`
M%'P(`Z:#P0`(."$`$$Z``"`0`E%4$``60!``6$`0`%D```(``5]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@`````!``8U@0`&-H$`!C<!``8W@0
M`&.`$`!B:!``8Y00`&.<$`!A.!``8F@0`&(0$`!B%!``8Z00`&%`$`!CK!``
M8F@0`&.P$`!CN!``8FA9@`````````````!!S____X```"5S+R5S````+W!R
M;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!P97)L
M>'-I+F,```!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E
M>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S
M```O````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\`
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?
M1$5"54<```!005)?0T%#2$4```!005)?05)'0P````!005)?05)'5E\P``!0
M05)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-
M4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%2
M7T-,14%./0``,0```%-94U1%30``)7,E<R5S)7,`````<&%R+0````!P87)L
M`````"YP87(`````)7,E<V-A8VAE+25S)7,``"4P,G@`````)7,E<W1E;7`M
M)74E<P```"5S)7-T96UP+25U+25U)7,`````05)'5@`````8````<&5R;```
M```P````)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN9R!W
M:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H````M
M90``+2T``$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42```
M``!$64Q$7TQ)0E)!4EE?4$%42````$,Z7%1%35``+W1M<`````!414U01$E2
M`%1-4`!54T52`````%5315).04U%`````",A+W5S<B]B:6XO<&5R;`IE=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF
M(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?
M7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@
M;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L
M:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL
M93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U
M:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@
M9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@
M=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@
M87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@
M(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R
M>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N
M<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D
M"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E
M(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S
M:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S
M92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN
M9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*
M("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@
M("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@
M5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3
M549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@
M("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G
M"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E
M86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H
M;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T
M;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@
M8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T
M<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@
M?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@
M9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?
M<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@
M86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6
M>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@
M("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK
M97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?
M05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#
M;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO
M(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA
M9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO
M9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I
M;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P
M96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?
M1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R
M96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN
M4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O
M<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I
M;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?
M;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*
M("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN
M*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF
M7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN
M960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2![
M"B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE
M*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@
M("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT
M("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@
M("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA
M;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@
M8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N
M86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@
M("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@
M;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@
M("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@
M)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L
M;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@
M("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@
M/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C
M86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@
M("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@
M("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@
M("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE
M9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@
M("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T
M;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@
M("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O
M=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C
M?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B
M:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL
M96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M
M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@
M("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE
M<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S
M:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE
M879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U
M;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@
M;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I
M<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@
M("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@
M("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T
M871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]
M?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M
M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)5
M1WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X
M96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O
M7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN
M<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E
M<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@
M87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!2
M3T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@
M<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@
M87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E
M;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@
M("`@)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@
M("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY
M($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@
M("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@
M("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@
M("`@979A;"`B=7-E("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P
M87)?87)G<RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@
M("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@
M("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`]
M(#$["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,
M)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R
M(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@
M("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@
M("`@("!S:&EF="A`05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@
M("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@
M("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PH@("`@("`@("`@("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@
M('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*
M?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*
M(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@
M("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?
M(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL
M93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@
M*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P
M87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B
M:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*
M"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D
M<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@
M("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S
M*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@
M("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@
M("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL
M97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P
M87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z
M("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@
M(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@
M("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R
M(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D
M("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&
M2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS
M;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^
M("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U
M8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL
M96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]
M"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@
M(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I
M9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@
M("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@
M:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@
M("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\
M/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O
M0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE
M(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@
M("`@("`C($9I;&4@97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y
M,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN
M+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@
M("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R
M87-P(&]F('1H92!I<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G
M;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA
M<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@
M("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N
M9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD
M7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N
M.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@
M("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@
M/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@
M("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<
M421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@
M("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@
M("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@
M("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@
M("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@
M("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N
M>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T
M<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E
M9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@
M("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D
M8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@
M("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&
M24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B
M.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@
M("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@
M1DE,13L*"B`@("`@("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@
M("`@("!I9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH
M/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@("`@("`@(R!$;R!N;W0@;&5T
M(%A33&]A9&5R('!I8VL@=7`@875T;R\J(&9R;VT@96YV:7)O;FUE;G0*("`@
M("`@("`@("`@("`@("1C;VYT96YT(#U^(',O9V]T;R`K<F5T<GD@*W5N;&5S
M<R`K+BHO9V]T;R!R971R>3LO"B`@("`@("`@("`@("`@("`@("`@:68@;&,H
M)&YA;64I(&5Q(&QC*")84TQO861E<BYP;2(I.PH@("`@("`@("`@("!]"@H@
M("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M90H@("`@("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*
M("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S
M('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP
M.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G
M-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@
M('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@
M("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@
M("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP
M(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@
M("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F
M:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@
M("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2
M(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A
M9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@
M>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@
M("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z
M.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@
M(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI
M.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N
M;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@
M("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;
M7B]=*RD*("`@("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@
M("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N
M86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I
M*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*("`@("`@("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@
M;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@
M("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@
M0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL
M93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U
M;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*
M<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I
M<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I
M;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI
M;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@
M<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97([
M"B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@
M("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*
M("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@
M("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL
M:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2
M.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I
M<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E
M<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@
M("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O
M9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI
M<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A
M<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*
M("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@
M("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H
M(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@
M;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E
M.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E
M9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G
M:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@
M("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@
M("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@
M(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R
M;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB
M+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@
M("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@
M("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S
M965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L
M("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@
M("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@
M("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@
M("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ
M4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@
M("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@
M("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@
M("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O
M9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@
M("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H
M("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@
M("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B
M.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I
M<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T
M.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I
M;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D
M9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E
M>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI
M;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T
M;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R
M971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@
M("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$[
M"B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I
M.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z
M.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*
M"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0
M?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@
M>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@
M("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF
M("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D
M0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O
M;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@
M('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@
M("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*
M("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA
M;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%
M?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!7
M1"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@
M(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D
M0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I
M;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H
M(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#
M($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT[
M"B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O
M*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@
M('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@
M("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@
M*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY
M("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%
M04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@
M("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@
M("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@
M("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@
M<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@
M;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C
M<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*
M("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC
M;&EN92`Q,#$R"@I?7T5.1%]?"@```'!A<BYP;````1L#.P```!`````!__]8
MZ````"@````0``````%Z4@`$?$$!&PP!`````!`````8__]8N````"0`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````_____P````#_____```````````0`=%,$`'.Z!`!SN@````!`````0``
M``$```*R`````0```P$````,$``5Z`````T0`&``;__^]1```:@````%$``)
M]`````80``*D````"@``!?8````+````$````!4``````````Q`!T``````"
M```#S````!0````'````%Q``$AQP````$`'/]`````<0`!%T````"```!'0`
M```)````#````!8`````;____A``$-1O____`````F____`0``_J````````
M````````````````````````````````````````````````````````````
M`!`!SP@``````````!``7H`0`%Z$$`!>B!``7HP0`%Z0$`!>E!``7I@0`%Z<
M$`!>H!``7J00`%ZH$`!>K!``7K`0`%ZT$`!>N!``7KP0`%[`$`!>Q!``7L@0
M`%[,$`!>T!``7M00`%[8$`!>W!``7N`0`%[D$`!>Z!``7NP0`%[P$`!>]!``
M7O@0`%[\$`!?`!``7P00`%\($`!?#!``7Q`0`%\4$`!?&!``7QP0`%\@$`!?
M)!``7R@0`%\L$`!?,!``7S00`%\X$`!?/!``7T`0`%]$$`!?2!``7TP0`%]0
M$`!?5!``7U@0`%]<$`!?8!``7V00`%]H$`!?;!``7W`0`%]T$`!?>!``7WP0
M`%^`$`!?A!``7X@0`%^,$`!?D!``7Y00`%^8$`!?G!``7Z`0`%^D$`!?J!``
M7ZP0`%^P$`!?M!``7[@0`%^\$`!?P````````````````/____\``%OI$`"_
ML$=#0SH@*%5B=6YT=2],:6YA<F\@-"XV+C$M,G5B=6YT=3$I(#0N-BXQ`$=#
M0SH@*%5B=6YT=2`T+C4N,RTQ=6)U;G1U,BD@-"XU+C,`00```!-G;G4``0``
M``L$`0@!#`(`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R
M86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9V]T,@`N9'EN86UI8P`N9V]T`"YD
M871A`"YS9&%T80`N8G-S`"YC;VUM96YT`"YG;G4N871T<FEB=71E<P``````
M``````````````````````````````````````````````````````L````!
M`````A```50```%4````#0```````````````0`````````3````!P````(0
M``%D```!9````"````````````````0`````````(0````<````"$``!A```
M`80````D```````````````$`````````#1O___V`````A```:@```&H````
M_`````4`````````!`````0````^````"P````(0``*D```"I```!U`````&
M`````0````0````0````1@````,````"$``)]```"?0```7V````````````
M```!`````````$YO____`````A``#^H```_J````Z@````4``````````@``
M``(```!;;____@````(0`!#4```0U````*`````&`````@````0`````````
M:@````0````"$``1=```$70```"H````!0`````````$````#````'0````$
M`````A``$AP``!(<```#S`````4````7````!`````P```!^`````0````80
M`!7H```5Z````$P```````````````0`````````A`````$````&$``60```
M%D```$G````````````````0`````````(H````!````!A``8````&``````
M.```````````````!`````````"0`````0````(0`&`X``!@.```7X``````
M``````````@`````````F`````$````"$`"_N```O[@````4````````````
M```$`````````*8````!`````A``O\P``+_,````+```````````````!```
M``````"P`````0````,0`<[H``#.Z`````@```````````````0`````````
MMP````$````#$`'.\```SO`````(```````````````$`````````+X````!
M`````Q`!SO@``,[X````!```````````````!`````````##`````0````,0
M`<[\``#._`````P```````````````$`````````R0````8````#$`'/"```
MSP@```#H````!@`````````$````"````-(````!`````Q`!S_```,_P````
M$```````````````!`````0```!Y`````0````,0`=````#0`````40`````
M``````````0`````````UP````$````#$`'11```T40````0````````````
M```$`````````-T````!`````Q`!T50``-%4````"```````````````!```
M``````#D````"`````,0`=%@``#17```$#````````````````@`````````
MZ0````$````P````````T5P```!-```````````````!`````0```/)O___U
M`````````````-&I````%````````````````0`````````!`````P``````
;``````#1O0```0(```````````````$`````
